scipy.odr.models
================

.. automodule:: scipy.odr.models

   
   
   .. rubric:: Functions

   .. autosummary::
   
      polynomial
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Model
   
   

   
   
   